@@ -31,7 +31,6 @@ class Server:
         self.app = app
 
     def run(self):
-        import os
         while True:
             with socket(AF_INET, SOCK_STREAM) as s:
                 try:
@@ -40,7 +39,6 @@ class Server:
                     error("Connect: %s", e)
                     sleep(2)
                     continue
-                print("Handling in", os.getpid())
 
                 try:
                     Handler(s, self.addr, server)
@@ -54,9 +52,8 @@ class Server:
 
 if __name__ == "__main__":
     from argparse import ArgumentParser
-    from asyncio import get_child_watcher, get_event_loop
     from importlib import import_module
-    from multiprocessing import Process
+    from threading import Thread
     from sys import path
 
     path.insert(0, ".")
@@ -79,19 +76,10 @@ if __name__ == "__main__":
         help="The WSGI request handler to handle requests")
     args = parser.parse_args()
 
-    loop = get_event_loop()
     server = Server(args.connect, args.app)
-    watcher = get_child_watcher()
-    watcher.attach_loop(loop)
 
-    def launch():
-        p = Process(target=server.run)
-        p.start()
-        watcher.add_child_handler(p.pid, lambda a, b: launch())
-
-    async def setup():
-        for _ in range(args.workers):
-            launch()
-
-    loop.run_until_complete(setup())
-    loop.run_forever()
+    workers = [Thread(target=server.run) for _ in range(args.workers)]
+    for worker in workers:
+        worker.start()
+    for worker in workers:
+        worker.join()
